## Usage
```sh
pip install py-node-exporter
python -m py-node-exporter [--port 9100]
```

## info
```
https://github.com/prometheus/node_exporter/tree/master/collector
https://wp.huangshiyang.com/prometheus-python-client-sample-server
```